@@ -1,4 +1,3 @@
-from operator import ge
 from koil.helpers import unkoil
 from koil.koil import Koil
 import inspect
@@ -60,7 +59,6 @@ def koilable(
             koil = getattr(self, fieldname, None)
             if koil is not None:
                 koil.__exit__(None, None, None)
-                setattr(self, fieldname, None)
 
         async def aexit(self):
             return await self.__aexit__(None, None, None)
