@@ -4,12 +4,10 @@ from dataclasses import dataclass
 import os
 import sys
 import threading
-from typing import Any, Optional, Type
+from typing import Any, Optional
 
-from pydantic import BaseModel, Field
 from koil.errors import ContextError
 from koil.vars import *
-from koil.task import KoilFuture, KoilRunner
 import time
 import logging
 
@@ -118,9 +116,10 @@ class KoilMixin:
     def __enter__(self):
         try:
             asyncio.get_running_loop()
-            raise ContextError(
-                "You are running in asyncio event loop already. Using koil makes no sense here, use asyncio instead. If this happens in a context manager, you probably forgot to use the `async with` syntax."
-            )
+            if not hasattr(self, "sync_in_async") or self.sync_in_async is False:
+                raise ContextError(
+                    "You are running in asyncio event loop already. Using koil makes no sense here, use asyncio instead. If this happens in a context manager, you probably forgot to use the `async with` syntax."
+                )
         except RuntimeError:
             pass
 
@@ -176,4 +175,3 @@ class Koil(KoilMixin):
     """How would you like to name this loop"""
 
     force_lonely: bool = False
-    pass
