@@ -3,15 +3,11 @@ import contextvars
 import inspect
 import logging
 import threading
-import uuid
-from asyncio.futures import Future
-from concurrent import futures
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import Callable, Generic, TypeVar
 
-from qtpy import QtCore, QtGui, QtWidgets
-from qtpy.QtCore import QObject, QThread, Signal
-from typing_extensions import ParamSpec, final
+from qtpy import QtCore, QtWidgets
+from typing_extensions import ParamSpec
 
 from koil.koil import Koil, KoilMixin
 from koil.task import KoilFuture, KoilGeneratorRunner, KoilRunner, KoilYieldFuture
@@ -58,6 +54,44 @@ class QtFuture:
         self.loop.call_soon_threadsafe(self.aiofuture.set_exception, exp)
 
 
+class KoilStopIteration(Exception):
+    pass
+
+
+class QtGenerator:
+    def __init__(self):
+        self.loop = asyncio.get_event_loop()
+        self.aioqueue = asyncio.Queue()
+        self.iscancelled = False
+
+    def _set_cancelled(self):
+        """WIll be called by the asyncio loop"""
+        self.iscancelled = True
+
+    def next(self, *args):
+        self.loop.call_soon_threadsafe(self.aioqueue.put_nowait, *args)
+
+    def throw(self, exception):
+        self.loop.call_soon_threadsafe(self.aioqueue.put_nowait, exception)
+
+    def stop(self):
+        self.loop.call_soon_threadsafe(self.aioqueue.put_nowait, KoilStopIteration())
+
+    def __aiter__(self):
+        return self
+
+    async def __anext__(self):
+        try:
+            res = await self.aioqueue.get()
+            if isinstance(res, KoilStopIteration):
+                raise StopAsyncIteration
+            if isinstance(res, Exception):
+                raise res
+        except asyncio.CancelledError:
+            raise StopAsyncIteration
+        return res
+
+
 T = TypeVar("T")
 P = ParamSpec("P")
 
@@ -213,6 +247,7 @@ class QtGeneratorRunner(KoilGeneratorRunner, QtCore.QObject):
 class QtKoilMixin(KoilMixin):
     def __enter__(self):
         super().__enter__()
+        assert self.parent, "Parent must be set before entering the loop"
         self._qobject = WrappedObject(parent=self.parent, koil=self)
         assert (
             self._qobject.parent() is not None
