@@ -1,14 +1,11 @@
-import contextvars
 import logging
-import asyncio
 import threading
-import time
-from typing import AsyncIterator, Awaitable, Callable, Coroutine, Generic, TypeVar
+from typing import AsyncIterator, Awaitable, Callable, Generic, TypeVar
 from koil.errors import CancelledError
 from koil.vars import current_cancel_event, current_loop
 import inspect
 from .utils import run_threaded_with_context
-from typing_extensions import ParamSpec, final
+from typing_extensions import ParamSpec
 import concurrent.futures
 
 logger = logging.getLogger(__name__)
@@ -75,7 +72,6 @@ class KoilFuture:
 
         for ctx, value in context.items():
             ctx.set(value)
-            print(ctx, value.__class__)
 
         return res
 
@@ -93,7 +89,6 @@ class KoilYieldFuture(KoilFuture):
 
         for ctx, value in context.items():
             ctx.set(value)
-            print(ctx, value.__class__)
 
         return res
 
@@ -120,6 +115,7 @@ class KoilRunner(Generic[T, P]):
         kwargs = {**self.kwargs, **kwargs}
 
         loop = current_loop.get()
+        assert loop is not None, "No loop found"
         assert loop.is_running(), "Loop is not running"
         assert not loop.is_closed(), "Loop is closed"
         cancel_event = threading.Event()
@@ -145,6 +141,7 @@ class KoilGeneratorRunner(Generic[P, T]):
 
     def run(self, *args: P.args, **kwargs: P.kwargs):
         loop = current_loop.get()
+        assert loop is not None, "No koiled loop found"
         assert loop.is_running(), "Loop is not running"
         assert not loop.is_closed(), "Loop is closed"
         ait = self.iterator(*self.args, **self.kwargs).__aiter__()
